## Overview
This file contains an overview of the result directory outputted by the GailBot transcription and analysis process.

Developed at: Human Interaction Lab at Tufts

## meta.json
The "meta.json" file contains the metadata for the transcription and analysis results: the settings profile used to generate the transcription, the date of transcription, the source files, and the plugin analysis results.

## Raw
The "raw" folder contains two sub-folders: "Media" and "Transcript". The "Media" folder contains the original source files used for the transcription. The "Transcript" folder contains the raw transcript of the source files, generated by the applied speech-to-text engine.

## Analysis
The "Analysis" folder contains the result of the analysis by the applied plugin suites. Each applied plugin suite is responsible for creating the format.md file in the analysis folder with more detailed information about the files generated by that plugin suite. If one or more plugin suite has been applied to this transcription, please see the format.md file in the "Analysis" folder for more details.

## Format

